@@ -83,7 +83,7 @@ class PathTests(TempDirTestCase):
 
     def test_cwd(self):
         path = Path('file_rx', mode='fr', cwd=os.path.join(self.tmpdir, 'dir_x'))
-        self.assertEqual(path.cwd, Path('file_rx', mode='fr', cwd=[path.cwd]).cwd)
+        self.assertEqual(path.cwd, Path('file_rx', mode='fr', cwd=path.cwd).cwd)
 
 
     def test_file_access_mode(self):
@@ -147,7 +147,7 @@ class PathTests(TempDirTestCase):
         self.assertEqual(path(True), os.path.join(self.tmpdir, self.file_rw))
         self.assertEqual(path(), os.path.join(self.tmpdir, self.file_rw))
         self.assertEqual(str(path), self.file_rw)
-        self.assertTrue(path.__repr__().startswith('Path('))
+        self.assertTrue(path.__repr__().startswith('Path_frw('))
 
 
     def test_tilde_home(self):
